@@ -26,7 +26,10 @@ def get(hub, raw_cli: Dict[str, Any], arg: str) -> Dict[str, Any]:
 
     if "dest" in signature.parameters:
         # This is the default for positional args
-        kwargs["dest"] = comps.pop("dest", arg)
+        if "dest" in comps:
+            kwargs["dest"] = comps["dest"]
+        else:
+            kwargs["dest"] = arg
     if "help" in signature.parameters:
         kwargs["help"] = comps.pop("help", "THIS NEEDS SOME DOCUMENTATION!!")
 
