@@ -11,6 +11,8 @@ from typing import Tuple
 
 import dict_tools.update
 
+LOADED_MOD_CHOICES = "loaded_mod_choices_ref"
+
 
 def load(hub, sources: List[str], dyne_names: List[str], cli: str):
     """
@@ -25,12 +27,20 @@ def load(hub, sources: List[str], dyne_names: List[str], cli: str):
     if not isinstance(sources, list):
         sources = [sources]
     raw = hub.config.dirs.find_configs(sources)
-    # Makes sure everything is unique
-    dnames = set(dyne_names)
+
+    # Make sure that all keys from the DYNES are in the dname sources
     for source in sources:
-        dnames.update(raw[source]["DYNE"].keys())
-    hub.config.dirs.resolve_sources(dnames, raw)
-    for name in dnames:
+        for name in raw[source]["DYNE"].keys():
+            if name not in dyne_names:
+                dyne_names.append(name)
+
+    # Make sure that the cli dyne name is processed last, so that it is authoritative on sourced defaults
+    while cli in dyne_names:
+        dyne_names.remove(cli)
+    dyne_names.append(cli)
+
+    hub.config.dirs.resolve_sources(dyne_names, raw)
+    for name in dyne_names:
         if name not in dyne:
             continue
         if name not in raw:
@@ -131,6 +141,16 @@ def parse_config(hub, dyne_data: Dict[str, Dict], cli: str) -> Dict:
 def parse_cli(hub, dyne_data: Dict, cli: str) -> Dict:
     cli_draw = {}
     for key, val in dyne_data["CLI_CONFIG"].items():
+        # Set the "choices" parameter based on loaded mods at the given ref
+        if val.get(LOADED_MOD_CHOICES):
+            ref = val.pop(LOADED_MOD_CHOICES)
+            try:
+                val["choices"] = sorted(
+                    name for name in hub[ref]._loaded if name != "init"
+                )
+            except AttributeError:
+                hub.log.debug(f"Could not load choices for ref: '{ref}'")
+
         new_dyne = val.get("dyne")
         if new_dyne == "__cli__":
             new_dyne = cli
