@@ -7,3 +7,5 @@ def __init__(hub):
     hub.config.ARGS = {}
     hub.config.SECTIONS = ("CONFIG", "CLI_CONFIG", "SUBCOMMANDS", "DYNE")
     hub.config.CONFIG_SECTIONS = ("CONFIG", "CLI_CONFIG")
+    # This can be dynamically extended by any project to ensure that their config gets loaded
+    hub.config.LOAD = ["pop_config"]
