@@ -26,6 +26,7 @@ def setup(hub, conf):
     ch.setLevel(hub.log.INT_LEVEL)
     ch.setFormatter(cf)
     root.addHandler(ch)
+    hub.log.handlers.addHandler(ch)
 
     ff = logging.Formatter(fmt=conf["log_fmt_logfile"], datefmt=conf["log_datefmt"])
     if ":" in conf["log_file"]:
@@ -41,3 +42,4 @@ def setup(hub, conf):
     fh.setLevel(hub.log.INT_LEVEL)
     fh.setFormatter(ff)
     root.addHandler(fh)
+    hub.log.handlers.addHandler(cf)
